==> openshift-model-5.4.1-sources.jar: io/fabric8/openshift/api/model/SchedulerSpecFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface SchedulerSpecFluent<A extends io.fabric8.openshift.api.model.SchedulerSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public java.lang.String getDefaultNodeSelector();
    public A withDefaultNodeSelector(java.lang.String defaultNodeSelector);
    public java.lang.Boolean hasDefaultNodeSelector();
    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withDefaultNodeSelector instead.
     */
        public A withNewDefaultNodeSelector(java.lang.String arg0);
    public java.lang.Boolean getMastersSchedulable();
    public A withMastersSchedulable(java.lang.Boolean mastersSchedulable);
    public java.lang.Boolean hasMastersSchedulable();
    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildPolicy instead.
     * @return The buildable object.
     */
        public io.fabric8.openshift.api.model.ConfigMapNameReference getPolicy();
    public io.fabric8.openshift.api.model.ConfigMapNameReference buildPolicy();
    public A withPolicy(io.fabric8.openshift.api.model.ConfigMapNameReference policy);
    public java.lang.Boolean hasPolicy();
    public A withNewPolicy(java.lang.String name);
    public io.fabric8.openshift.api.model.SchedulerSpecFluent.PolicyNested<A> withNewPolicy();
    public io.fabric8.openshift.api.model.SchedulerSpecFluent.PolicyNested<A> withNewPolicyLike(io.fabric8.openshift.api.model.ConfigMapNameReference item);
    public io.fabric8.openshift.api.model.SchedulerSpecFluent.PolicyNested<A> editPolicy();
    public io.fabric8.openshift.api.model.SchedulerSpecFluent.PolicyNested<A> editOrNewPolicy();
    public io.fabric8.openshift.api.model.SchedulerSpecFluent.PolicyNested<A> editOrNewPolicyLike(io.fabric8.openshift.api.model.ConfigMapNameReference item);
    public interface PolicyNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.ConfigMapNameReferenceFluent<io.fabric8.openshift.api.model.SchedulerSpecFluent.PolicyNested<N>> {

            public N and();
            public N endPolicy();    }


}

==> openshift-model-5.7.0-sources.jar: io/fabric8/openshift/api/model/SchedulerSpecFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface SchedulerSpecFluent<A extends io.fabric8.openshift.api.model.SchedulerSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public java.lang.String getDefaultNodeSelector();
    public A withDefaultNodeSelector(java.lang.String defaultNodeSelector);
    public java.lang.Boolean hasDefaultNodeSelector();
    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withDefaultNodeSelector instead.
     */
        public A withNewDefaultNodeSelector(java.lang.String arg0);
    public java.lang.Boolean getMastersSchedulable();
    public A withMastersSchedulable(java.lang.Boolean mastersSchedulable);
    public java.lang.Boolean hasMastersSchedulable();
    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildPolicy instead.
     * @return The buildable object.
     */
        public io.fabric8.openshift.api.model.ConfigMapNameReference getPolicy();
    public io.fabric8.openshift.api.model.ConfigMapNameReference buildPolicy();
    public A withPolicy(io.fabric8.openshift.api.model.ConfigMapNameReference policy);
    public java.lang.Boolean hasPolicy();
    public A withNewPolicy(java.lang.String name);
    public io.fabric8.openshift.api.model.SchedulerSpecFluent.PolicyNested<A> withNewPolicy();
    public io.fabric8.openshift.api.model.SchedulerSpecFluent.PolicyNested<A> withNewPolicyLike(io.fabric8.openshift.api.model.ConfigMapNameReference item);
    public io.fabric8.openshift.api.model.SchedulerSpecFluent.PolicyNested<A> editPolicy();
    public io.fabric8.openshift.api.model.SchedulerSpecFluent.PolicyNested<A> editOrNewPolicy();
    public io.fabric8.openshift.api.model.SchedulerSpecFluent.PolicyNested<A> editOrNewPolicyLike(io.fabric8.openshift.api.model.ConfigMapNameReference item);
    public java.lang.String getProfile();
    public A withProfile(java.lang.String profile);
    public java.lang.Boolean hasProfile();
    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withProfile instead.
     */
        public A withNewProfile(java.lang.String arg0);
    public interface PolicyNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.ConfigMapNameReferenceFluent<io.fabric8.openshift.api.model.SchedulerSpecFluent.PolicyNested<N>> {

            public N and();
            public N endPolicy();    }


}
